import React, { useState, useEffect, useCallback } from 'react';

var CursorWavePattern = function (_a) {
    var _b = _a.gridSize, gridSize = _b === void 0 ? 20 : _b, _c = _a.spacing, spacing = _c === void 0 ? 40 : _c, _d = _a.waveSpeed, waveSpeed = _d === void 0 ? 0.05 : _d, _e = _a.primaryWaveFrequency, primaryWaveFrequency = _e === void 0 ? 0.05 : _e, _f = _a.secondaryWaveFrequency, secondaryWaveFrequency = _f === void 0 ? 0.02 : _f, _g = _a.cursorInfluenceRadius, cursorInfluenceRadius = _g === void 0 ? 200 : _g, _h = _a.backgroundColor, backgroundColor = _h === void 0 ? 'rgb(17, 24, 39)' : _h, _j = _a.dotColor, dotColor = _j === void 0 ? 'rgb(96, 165, 250)' : _j;
    var _k = useState({ x: 0, y: 0 }), mousePosition = _k[0], setMousePosition = _k[1];
    var _l = useState(0), time = _l[0], setTime = _l[1];
    var _m = useState([]), dots = _m[0], setDots = _m[1];
    useEffect(function () {
        var handleMouseMove = function (event) {
            var clientX = event.clientX, clientY = event.clientY;
            setMousePosition({ x: clientX, y: clientY });
        };
        window.addEventListener('mousemove', handleMouseMove);
        return function () { return window.removeEventListener('mousemove', handleMouseMove); };
    }, []);
    useEffect(function () {
        var animationFrameId;
        var animate = function () {
            setTime(function (prev) { return prev + waveSpeed; });
            animationFrameId = requestAnimationFrame(animate);
        };
        animationFrameId = requestAnimationFrame(animate);
        return function () { return cancelAnimationFrame(animationFrameId); };
    }, [waveSpeed]);
    var calculateWaveOffset = useCallback(function (x, y, time) {
        var dx = x - mousePosition.x;
        var dy = y - mousePosition.y;
        var distance = Math.sqrt(dx * dx + dy * dy);
        var wave1 = Math.sin(distance * primaryWaveFrequency - time) * 15;
        var wave2 = Math.sin(distance * secondaryWaveFrequency - time * 0.5) * 10;
        var cursorEffect = Math.max(0, 1 - distance / cursorInfluenceRadius) * 20;
        return wave1 + wave2 + cursorEffect;
    }, [mousePosition, primaryWaveFrequency, secondaryWaveFrequency, cursorInfluenceRadius]);
    useEffect(function () {
        var generateDots = function () {
            var newDots = [];
            var offset = (gridSize * spacing) / 2;
            for (var i = 0; i < gridSize; i++) {
                for (var j = 0; j < gridSize; j++) {
                    var baseX = mousePosition.x - offset + (i * spacing);
                    var baseY = mousePosition.y - offset + (j * spacing);
                    var waveOffset = calculateWaveOffset(baseX, baseY, time);
                    var x = baseX;
                    var y = baseY + waveOffset;
                    var distance = Math.sqrt(Math.pow((mousePosition.x - x), 2) +
                        Math.pow((mousePosition.y - y), 2));
                    var size = Math.max(3, 8 - (distance / 100));
                    var opacity = Math.max(0.2, 1 - (distance / 400));
                    newDots.push({ x: x, y: y, size: size, opacity: opacity });
                }
            }
            setDots(newDots);
        };
        generateDots();
    }, [mousePosition, time, calculateWaveOffset, gridSize, spacing]);
    return (React.createElement("div", { style: {
            position: 'fixed',
            inset: 0,
            backgroundColor: backgroundColor,
            overflow: 'hidden'
        } },
        React.createElement("div", { style: { position: 'relative', width: '100%', height: '100%' } },
            React.createElement("div", { style: {
                    position: 'fixed',
                    width: '24px',
                    height: '24px',
                    backgroundColor: dotColor,
                    borderRadius: '50%',
                    pointerEvents: 'none',
                    transform: "translate(".concat(mousePosition.x - 12, "px, ").concat(mousePosition.y - 12, "px)"),
                    transition: 'transform 0.1s ease-out',
                    boxShadow: "0 0 20px ".concat(dotColor, "80")
                } }),
            dots.map(function (dot, index) { return (React.createElement("div", { key: index, style: {
                    position: 'fixed',
                    width: "".concat(dot.size, "px"),
                    height: "".concat(dot.size, "px"),
                    transform: "translate(".concat(dot.x - dot.size / 2, "px, ").concat(dot.y - dot.size / 2, "px)"),
                    backgroundColor: dotColor,
                    borderRadius: '50%',
                    opacity: dot.opacity,
                    pointerEvents: 'none',
                    transition: 'opacity 0.2s ease-out'
                } })); }))));
};

export { CursorWavePattern };
